searchNodes=[{"ref":"Unicode.html","title":"Unicode","type":"module","doc":"Functions to introspect the Unicode character database and to provide fast codepoint lookups for scripts, blocks, categories and properties."},{"ref":"Unicode.html#alphabetic?/1","title":"Unicode.alphabetic?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) adhere to the Derived Core Property Alphabetic otherwise returns false. These are all characters that are usually used as representations of letters/syllabes in words/sentences. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.alphabetic?(?a) true iex&gt; Unicode.alphabetic?(&quot;A&quot;) true iex&gt; Unicode.alphabetic?(&quot;Elixir&quot;) true iex&gt; Unicode.alphabetic?(&quot;الإكسير&quot;) true # comma and whitespace iex&gt; Unicode.alphabetic?(&quot;foo, bar&quot;) false iex&gt; Unicode.alphabetic?(&quot;42&quot;) false iex&gt; Unicode.alphabetic?(&quot;龍王&quot;) true # Summation, ∑ iex&gt; Unicode.alphabetic?(&quot;∑&quot;) false # Greek capital letter sigma, Σ iex&gt; Unicode.alphabetic?(&quot;Σ&quot;) true"},{"ref":"Unicode.html#alphanumeric?/1","title":"Unicode.alphanumeric?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) are either alphabetic?/1 or numeric?/1 otherwise returns false. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.alphanumeric? &quot;1234&quot; true iex&gt; Unicode.alphanumeric? &quot;KeyserSöze1995&quot; true iex&gt; Unicode.alphanumeric? &quot;3段&quot; true iex&gt; Unicode.alphanumeric? &quot;dragon@example.com&quot; false"},{"ref":"Unicode.html#block/1","title":"Unicode.block/1","type":"function","doc":"Returns the block name of a codepoint or the list of block names for each codepoint in a string. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, an atom block name in the case of a string, a list of atom block names for each codepoint in the codepoint_or_string Exmaples iex&gt; Unicode.block ?ä :latin_1_supplement iex&gt; Unicode.block ?A :basic_latin iex&gt; Unicode.block &quot;äA&quot; [:latin_1_supplement, :basic_latin]"},{"ref":"Unicode.html#cased?/1","title":"Unicode.cased?/1","type":"function","doc":"Returns either true if the codepoint has the :cased property or false. The :cased property means that this character has at least an upper and lower representation and possibly a titlecase representation too. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.cased? ?ယ false iex&gt; Unicode.cased? ?A true"},{"ref":"Unicode.html#category/1","title":"Unicode.category/1","type":"function","doc":"Returns the Unicode category for a codepoint or a list of categories for a string. Argument codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, an atom representing one of the categories listed below in the case of a string, a list representing the category for each codepoint in the string Notes THese categories match the names of the Unicode character classes used in various regular expression engines and in Unicode Sets. The full list of categories is: CategoryMatches :COther :CcControl :CfFormat :CnUnassigned :CoPrivate use :CsSurrogate :LLetter :LlLower case letter :LmModifier letter :LoOther letter :LtTitle case letter :LuUpper case letter :MMark :McSpacing mark :MeEnclosing mark :MnNon-spacing mark :NNumber :NdDecimal number :NlLetter number :NoOther number :PPunctuation :PcConnector punctuation :PdDash punctuation :PeClose punctuation :PfFinal punctuation :PiInitial punctuation :PoOther punctuation :PsOpen punctuation :SSymbol :ScCurrency symbol :SkModifier symbol :SmMathematical symbol :SoOther symbol :ZSeparator :ZlLine separator :ZpParagraph separator :ZsSpace separator Note too that the group level categories like :L, :M, :S and so on are not assigned to any codepoint. They can only be identified by combining the results for each of the subsidiary categories. Examples iex&gt; Unicode.category ?ä :Ll iex&gt; Unicode.category ?A :Lu iex&gt; Unicode.category ?🧐 :So iex&gt; Unicode.category ?+ :Sm iex&gt; Unicode.category ?1 :Nd iex&gt; Unicode.category &quot;äA&quot; [:Ll, :Lu]"},{"ref":"Unicode.html#digits?/1","title":"Unicode.digits?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) adhere to Unicode category :Nd otherwise returns false. This group of characters represents the decimal digits zero through nine (0..9) and the equivalents in non-Latin scripts. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples"},{"ref":"Unicode.html#downcase?/1","title":"Unicode.downcase?/1","type":"function","doc":"See Unicode.Property.lowercase?/1."},{"ref":"Unicode.html#emoji?/1","title":"Unicode.emoji?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) are emoji otherwise returns false. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.emoji? &quot;🧐🤓🤩🤩️🤯&quot; true"},{"ref":"Unicode.html#fetch_property/1","title":"Unicode.fetch_property/1","type":"function","doc":""},{"ref":"Unicode.html#get_property/1","title":"Unicode.get_property/1","type":"function","doc":""},{"ref":"Unicode.html#lowercase?/1","title":"Unicode.lowercase?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) the category :Ll otherwise returns false. Notice that there are many languages that do not have a distinction between cases. Their characters are not included in this group. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.lowercase?(?a) true iex&gt; Unicode.lowercase?(&quot;A&quot;) false iex&gt; Unicode.lowercase?(&quot;Elixir&quot;) false iex&gt; Unicode.lowercase?(&quot;léon&quot;) true iex&gt; Unicode.lowercase?(&quot;foo, bar&quot;) false iex&gt; Unicode.lowercase?(&quot;42&quot;) false iex&gt; Unicode.lowercase?(&quot;Σ&quot;) false iex&gt; Unicode.lowercase?(&quot;σ&quot;) true"},{"ref":"Unicode.html#math?/1","title":"Unicode.math?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) the category :Sm otherwise returns false. These are all characters whose primary usage is in mathematical concepts (and not in alphabets). Notice that the numerical digits are not part of this group. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.math?(?=) true iex&gt; Unicode.math?(&quot;=&quot;) true iex&gt; Unicode.math?(&quot;1+1=2&quot;) # Digits do not have the `:math` property. false iex&gt; Unicode.math?(&quot;परिस&quot;) false iex&gt; Unicode.math?(&quot;∑&quot;) # Summation, \\u2211 true iex&gt; Unicode.math?(&quot;Σ&quot;) # Greek capital letter sigma, \\u03a3 false"},{"ref":"Unicode.html#numeric?/1","title":"Unicode.numeric?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) adhere to Unicode categories :Nd, :Nl and :No otherwise returns false. This group of characters represents the decimal digits zero through nine (0..9) and the equivalents in non-Latin scripts. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.numeric?(&quot;65535&quot;) true iex&gt; Unicode.numeric?(&quot;42&quot;) true iex&gt; Unicode.numeric?(&quot;lapis philosophorum&quot;) false"},{"ref":"Unicode.html#properties/1","title":"Unicode.properties/1","type":"function","doc":"Returns the list of properties of each codepoint in a given string or the list of properties for a given string. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, an atom list of properties in the case of a string, a list of atom lisr for each codepoint in the codepoint_or_string Exmaples iex&gt; Unicode.properties 0x1bf0 [ :alphabetic, :case_ignorable, :grapheme_extend, :id_continue, :other_alphabetic, :xid_continue ] iex&gt; Unicode.properties ?A [ :alphabetic, :ascii_hex_digit, :cased, :changes_when_casefolded, :changes_when_casemapped, :changes_when_lowercased, :grapheme_base, :hex_digit, :id_continue, :id_start, :uppercase, :xid_continue, :xid_start ] iex&gt; Unicode.properties ?+ [:grapheme_base, :math, :pattern_syntax] iex&gt; Unicode.properties &quot;a1+&quot; [ [ :alphabetic, :ascii_hex_digit, :cased, :changes_when_casemapped, :changes_when_titlecased, :changes_when_uppercased, :grapheme_base, :hex_digit, :id_continue, :id_start, :lowercase, :xid_continue, :xid_start ], [ :ascii_hex_digit, :grapheme_base, :hex_digit, :id_continue, :xid_continue ], [ :grapheme_base, :math, :pattern_syntax ] ]"},{"ref":"Unicode.html#property_servers/0","title":"Unicode.property_servers/0","type":"function","doc":"Returns a map of aliases mapping property names to a module that serves that property"},{"ref":"Unicode.html#ranges/0","title":"Unicode.ranges/0","type":"function","doc":"Returns a list of tuples representing the valid ranges of Unicode code points. This information is derived from the block ranges as defined by Unicode.Block.blocks/0."},{"ref":"Unicode.html#script/1","title":"Unicode.script/1","type":"function","doc":"Returns the script name of a codepoint or the list of block names for each codepoint in a string. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns in the case of a single codepoint, a string script name in the case of a string, a list of string script names for each codepoint in the codepoint_or_string Exmaples iex&gt; Unicode.script ?ä :latin iex&gt; Unicode.script ?خ :arabic iex&gt; Unicode.script ?अ :devanagari iex&gt; Unicode.script ?א :hebrew iex&gt; Unicode.script ?Ж :cyrillic iex&gt; Unicode.script ?δ :greek iex&gt; Unicode.script ?ก :thai iex&gt; Unicode.script ?ယ :myanmar"},{"ref":"Unicode.html#unaccent/1","title":"Unicode.unaccent/1","type":"function","doc":"Removes accents (diacritical marks) from a string. Arguments string is any String.t Returns A string with all diacritical marks removed Notes The string is first normalised to :nfd form and then all characters in the block :comnbining_diacritical_marks is removed from the string Example iex&gt; Unicode.unaccent(&quot;Et Ça sera sa moitié.&quot;) &quot;Et Ca sera sa moitie.&quot;"},{"ref":"Unicode.html#upcase?/1","title":"Unicode.upcase?/1","type":"function","doc":"See Unicode.Property.uppercase?/1."},{"ref":"Unicode.html#uppercase?/1","title":"Unicode.uppercase?/1","type":"function","doc":"Returns true if a single Unicode codepoint (or all characters in the given string) the category :Lu otherwise returns false. Notice that there are many languages that do not have a distinction between cases. Their characters are not included in this group. Arguments codepoint_or_string is a single integer codepoint or a String.t. Returns true or false For the string-version, the result will be true only if all codepoints in the string adhere to the property. Examples iex&gt; Unicode.uppercase?(?a) false iex&gt; Unicode.uppercase?(&quot;A&quot;) true iex&gt; Unicode.uppercase?(&quot;Elixir&quot;) false iex&gt; Unicode.uppercase?(&quot;CAMEMBERT&quot;) true iex&gt; Unicode.uppercase?(&quot;foo, bar&quot;) false iex&gt; Unicode.uppercase?(&quot;42&quot;) false iex&gt; Unicode.uppercase?(&quot;Σ&quot;) true iex&gt; Unicode.uppercase?(&quot;σ&quot;) false"},{"ref":"Unicode.html#version/0","title":"Unicode.version/0","type":"function","doc":"Returns the version of Unicode in use."},{"ref":"Unicode.html#t:codepoint/0","title":"Unicode.codepoint/0","type":"type","doc":""},{"ref":"Unicode.html#t:codepoint_or_string/0","title":"Unicode.codepoint_or_string/0","type":"type","doc":""},{"ref":"Unicode.Block.html","title":"Unicode.Block","type":"module","doc":"Functions to introspect Unicode blocks for binaries (Strings) and codepoints."},{"ref":"Unicode.Block.html#aliases/0","title":"Unicode.Block.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode blocks. An alias is an alternative name for referring to a block. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.Block.html#block/1","title":"Unicode.Block.block/1","type":"function","doc":"Returns the block name(s) for the given binary or codepoint. In the case of a codepoint, a single block name is returned. For a binary a list of distinct block names represented by the graphemes in the binary is returned."},{"ref":"Unicode.Block.html#blocks/0","title":"Unicode.Block.blocks/0","type":"function","doc":"Returns the map of Unicode blocks. The block name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.Block.html#count/1","title":"Unicode.Block.count/1","type":"function","doc":"Returns the count of the number of characters for a given block. Aliases are resolved by this function. Example iex&gt; Unicode.Block.count(:old_north_arabian) 32"},{"ref":"Unicode.Block.html#fetch/1","title":"Unicode.Block.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given block as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.Block.html#get/1","title":"Unicode.Block.get/1","type":"function","doc":"Returns the Unicode ranges for a given block as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.Block.html#known_blocks/0","title":"Unicode.Block.known_blocks/0","type":"function","doc":"Returns a list of known Unicode block names. This function does not return the names of any block aliases."},{"ref":"Unicode.Block.html#ranges/0","title":"Unicode.Block.ranges/0","type":"function","doc":"Returns a list of tuples representing the valid ranges of all Unicode code points."},{"ref":"Unicode.CanonicalCombiningClass.html","title":"Unicode.CanonicalCombiningClass","type":"module","doc":"Functions to introspect Unicode canonical combining classes for binaries (Strings) and codepoints."},{"ref":"Unicode.CanonicalCombiningClass.html#aliases/0","title":"Unicode.CanonicalCombiningClass.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode canonical combining classes.. An alias is an alternative name for referring to a class. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.CanonicalCombiningClass.html#combining_class/1","title":"Unicode.CanonicalCombiningClass.combining_class/1","type":"function","doc":"Returns the canonical combining class name(s) for the given binary or codepoint. In the case of a codepoint, a single class name is returned. For a binary a list of distinct class names represented by the graphemes in the binary is returned."},{"ref":"Unicode.CanonicalCombiningClass.html#combining_classes/0","title":"Unicode.CanonicalCombiningClass.combining_classes/0","type":"function","doc":"Returns the map of Unicode canonical combining classes.. The class name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.CanonicalCombiningClass.html#count/1","title":"Unicode.CanonicalCombiningClass.count/1","type":"function","doc":"Returns the count of the number of characters for a given canonical combining class. Example iex&gt; Unicode.CanonicalCombiningClass.count(230) 484"},{"ref":"Unicode.CanonicalCombiningClass.html#fetch/1","title":"Unicode.CanonicalCombiningClass.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given canonical combining class as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.CanonicalCombiningClass.html#get/1","title":"Unicode.CanonicalCombiningClass.get/1","type":"function","doc":"Returns the Unicode ranges for a given canonical combining class as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.CanonicalCombiningClass.html#known_combining_classes/0","title":"Unicode.CanonicalCombiningClass.known_combining_classes/0","type":"function","doc":"Returns a list of known Unicode canonical combining class names. This function does not return the names of any class aliases."},{"ref":"Unicode.Category.QuoteMarks.html","title":"Unicode.Category.QuoteMarks","type":"module","doc":"Functions to return codepoints that form quotation marks. These marks are taken from the Wikipedia definition which is more expansive than the Unicode categories Pi and Pf. The full list of codepoints considered to be quote marks is tabled here. Unicode code point table These are codepoints noted in the Unicode character data base with the flag quotation mark = yes. These are equivalent to the unicode sets Pi and Pf. GlyphCodeUnicode nameHTMLComments &quot;U+0022Quotation mark&amp;quot;Typewriter (&quot;programmer&#39;s&quot;) quote, ambidextrous. Also known as &quot;double quote&quot;. &#39;U+0027Apostrophe&amp;#39;Typewriter (&quot;programmer&#39;s&quot;) straight single quote, ambidextrous «U+00ABLeft-pointing double angle quotation mark&amp;laquo;Double angle quote »U+00BBRight-pointing double angle quotation mark&amp;raquo;Double angle quote, right ‘U+2018Left single quotation mark&amp;lsquo;Single curved quote, left. Also known as &#39;&#39;inverted [[comma]]&#39;&#39; or &#39;&#39;turned comma&#39;&#39; ’U+2019Right single quotation mark&amp;rsquo;Single curved quote, right ‚U+201ASingle low-9 quotation mark&amp;sbquo;Low single curved quote, left ‛U+201BSingle high-reversed-9 quotation mark&amp;#8219;also called &#39;&#39;single reversed comma&#39;&#39;, &#39;&#39;quotation mark&#39;&#39; “U+201CLeft double quotation mark&amp;ldquo;Double curved quote, left ”U+201DRight double quotation mark&amp;rdquo;Double curved quote, right „U+201EDouble low-9 quotation mark&amp;bdquo;Low double curved quote, left ‟U+201FDouble high-reversed-9 quotation mark&amp;#8223;also called &#39;&#39;double reversed comma&#39;&#39;, &#39;&#39;quotation mark&#39;&#39; ‹U+2039Single left-pointing angle quotation mark&amp;lsaquo;Single angle quote, left ›U+203ASingle right-pointing angle quotation mark&amp;rsaquo;Single angle quote, right ⹂U+2E42Double low-reversed-9 quotation mark&amp;#11842;also called &#39;&#39;double low reversed comma&#39;&#39;, &#39;&#39;quotation mark&#39;&#39; Quotation marks in dingbats GlyphCodeUnicode nameHTMLComments ❛U+275BHeavy single turned comma quotation mark ornament&amp;#10075;Quotation Mark=No ❜U+275CHeavy single comma quotation mark ornament&amp;#10076;Quotation Mark=No ❝U+275DHeavy double turned comma quotation mark ornament&amp;#10077;Quotation Mark=No ❞U+275EHeavy double comma quotation mark ornament&amp;#10078;Quotation Mark=No 🙶U+1F676SANS-SERIF HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT&amp;#128630;Quotation Mark=No 🙷U+1F677SANS-SERIF HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT&amp;#128631;Quotation Mark=No 🙸U+1F678SANS-SERIF HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT&amp;#128632;Quotation Mark=No Quotation marks in Braille Patterns GlyphCodeUnicode nameHTMLComments ⠦U+2826Braille pattern dots-236&amp;#10292;Braille double closing quotation mark; Quotation Mark=No ⠴U+2834Braille pattern dots-356&amp;#10278;Braille double opening quotation mark; Quotation Mark=No Quotation marks in Chinese, Japanese, and Korean GlyphCodeUnicode nameHTMLComments 「U+300CLeft corner bracket&amp;#12300;CJK 」U+300DRight corner bracket&amp;#12301;CJK 『U+300ELeft white corner bracket&amp;#12302;CJK 』U+300FRight white corner bracket&amp;#12303;CJK 〝U+301DREVERSED DOUBLE PRIME QUOTATION MARK&amp;#12317;CJK 〞U+301EDOUBLE PRIME QUOTATION MARK&amp;#12318;CJK 〟U+301FLOW DOUBLE PRIME QUOTATION MARK&amp;#12319;CJK Alternate encodings GlyphCodeUnicode nameHTMLComments ﹁U+FE41PRESENTATION FORM FOR VERTICAL LEFT CORNER BRACKET&amp;#65089;CJK Compatibility, preferred use: U+300C ﹂U+FE42PRESENTATION FORM FOR VERTICAL RIGHT CORNER BRACKET&amp;#65090;CJK Compatibility, preferred use: U+300D ﹃U+FE43PRESENTATION FORM FOR VERTICAL LEFT WHITE CORNER BRACKET&amp;#65091;CJK Compatibility, preferred use: U+300E ﹄U+FE44PRESENTATION FORM FOR VERTICAL RIGHT WHITE CORNER BRACKET&amp;#65092;CJK Compatibility, preferred use: U+300F ＂U+FF02FULLWIDTH QUOTATION MARK&amp;#65282;Halfwidth and Fullwidth Forms, corresponds with U+0022 ＇U+FF07FULLWIDTH apostrophe&amp;#65287;Halfwidth and Fullwidth Forms, corresponds with U+0027 ｢U+FF62HALFWIDTH LEFT CORNER BRACKET&amp;#65378;Halfwidth and Fullwidth Forms, corresponds with U+300C ｣U+FF63HALFWIDTH right CORNER BRACKET&amp;#65379;Halfwidth and Fullwidth Forms, corresponds with U+300D"},{"ref":"Unicode.Category.QuoteMarks.html#all_quote_marks/0","title":"Unicode.Category.QuoteMarks.all_quote_marks/0","type":"function","doc":"Return a list of codepoints representing all quote marks."},{"ref":"Unicode.Category.QuoteMarks.html#quote_marks_ambidextrous/0","title":"Unicode.Category.QuoteMarks.quote_marks_ambidextrous/0","type":"function","doc":"Return a list of codepoints representing quote marks typically used on the left or right (for LTR languages)"},{"ref":"Unicode.Category.QuoteMarks.html#quote_marks_braille/0","title":"Unicode.Category.QuoteMarks.quote_marks_braille/0","type":"function","doc":"Return a list of codepoints representing quote marks typically used in Braille"},{"ref":"Unicode.Category.QuoteMarks.html#quote_marks_double/0","title":"Unicode.Category.QuoteMarks.quote_marks_double/0","type":"function","doc":"Return a list of codepoints representing quote marks understood to be double marks"},{"ref":"Unicode.Category.QuoteMarks.html#quote_marks_left/0","title":"Unicode.Category.QuoteMarks.quote_marks_left/0","type":"function","doc":"Return a list of codepoints representing quote marks typically used on the left (for LTR languages)"},{"ref":"Unicode.Category.QuoteMarks.html#quote_marks_right/0","title":"Unicode.Category.QuoteMarks.quote_marks_right/0","type":"function","doc":"Return a list of codepoints representing quote marks typically used on the right (for LTR languages)"},{"ref":"Unicode.Category.QuoteMarks.html#quote_marks_single/0","title":"Unicode.Category.QuoteMarks.quote_marks_single/0","type":"function","doc":"Return a list of codepoints representing quote marks understood to be single marks"},{"ref":"Unicode.GeneralCategory.html","title":"Unicode.GeneralCategory","type":"module","doc":"Functions to introspect Unicode general categories for binaries (Strings) and codepoints."},{"ref":"Unicode.GeneralCategory.html#aliases/0","title":"Unicode.GeneralCategory.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode categories. An alias is an alternative name for referring to a category. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.GeneralCategory.html#categories/0","title":"Unicode.GeneralCategory.categories/0","type":"function","doc":"Returns the map of Unicode character categories. The category name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.GeneralCategory.html#category/1","title":"Unicode.GeneralCategory.category/1","type":"function","doc":"Returns the category name(s) for the given binary or codepoint. In the case of a codepoint, a single category name is returned. For a binary a list of distinct category names represented by the graphemes in the binary is returned. Only concrete general categories are considered, derived categories (:all, :ascii, :assigned etc) are not considered."},{"ref":"Unicode.GeneralCategory.html#count/1","title":"Unicode.GeneralCategory.count/1","type":"function","doc":"Return the count of characters in a given category. Example iex&gt; Unicode.GeneralCategory.count(:Ll) 2155 iex&gt; Unicode.GeneralCategory.count(:Nd) 650"},{"ref":"Unicode.GeneralCategory.html#fetch/1","title":"Unicode.GeneralCategory.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given category as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.GeneralCategory.html#get/1","title":"Unicode.GeneralCategory.get/1","type":"function","doc":"Returns the Unicode ranges for a given category as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.GeneralCategory.html#known_categories/0","title":"Unicode.GeneralCategory.known_categories/0","type":"function","doc":"Returns a list of known Unicode category names. This function does not return the names of any category aliases."},{"ref":"Unicode.GeneralCategory.Derived.html","title":"Unicode.GeneralCategory.Derived","type":"module","doc":"For certain operations and transformations (especially in Unicode Sets) there is an expectation that certain derived general categories exists even though they are not defined in the unicode character database. These categories are: :any which is the full unicode character range 0x0..0x10ffff :assigned which is the set of codepoints that are assigned and which is therefore equivalent to :any - :Cn. In fact that is exactly how it is calculated using unicode_set and the results are statically copied here so that there is no mutual dependency. :ascii which is the range for the US ASCII character set of 0x0..0x7f In addition there are derived categories not part of the Unicode specification that support additional use cases. These include: Categories related to recognising quotation marks. See the module Unicode.Category.QuoteMarks. :printable: which implements the same semantics as String.printable?/1 :visible: which includes characters from the [[:L:][:N:][:M:][:P:][:S:][:Zs:]] set"},{"ref":"Unicode.GeneralCategory.Derived.html#aliases/0","title":"Unicode.GeneralCategory.Derived.aliases/0","type":"function","doc":"Returns a map of the aliases for the derived General Categories"},{"ref":"Unicode.GeneralCategory.Derived.html#categories/0","title":"Unicode.GeneralCategory.Derived.categories/0","type":"function","doc":"Returns a map of the derived General Categories"},{"ref":"Unicode.GraphemeClusterBreak.html","title":"Unicode.GraphemeClusterBreak","type":"module","doc":"Functions to introspect Unicode grapheme cluster breaks for binaries (Strings) and codepoints."},{"ref":"Unicode.GraphemeClusterBreak.html#aliases/0","title":"Unicode.GraphemeClusterBreak.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode grapheme cluster breaks. An alias is an alternative name for referring to a grapheme cluster break. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.GraphemeClusterBreak.html#count/1","title":"Unicode.GraphemeClusterBreak.count/1","type":"function","doc":"Returns the count of the number of characters for a given grapheme cluster break. Example iex&gt; Unicode.GraphemeClusterBreak.count(:prepend) 24"},{"ref":"Unicode.GraphemeClusterBreak.html#fetch/1","title":"Unicode.GraphemeClusterBreak.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given grapheme cluster break as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.GraphemeClusterBreak.html#get/1","title":"Unicode.GraphemeClusterBreak.get/1","type":"function","doc":"Returns the Unicode ranges for a given grapheme cluster break as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.GraphemeClusterBreak.html#grapheme_break/1","title":"Unicode.GraphemeClusterBreak.grapheme_break/1","type":"function","doc":"Returns the grapheme cluster break name(s) for the given binary or codepoint. In the case of a codepoint, a single grapheme cluster break name is returned. For a binary a list of distinct grapheme cluster break names represented by the graphemes in the binary is returned."},{"ref":"Unicode.GraphemeClusterBreak.html#grapheme_breaks/0","title":"Unicode.GraphemeClusterBreak.grapheme_breaks/0","type":"function","doc":"Returns the map of Unicode grapheme cluster breaks. The grapheme cluster break name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.GraphemeClusterBreak.html#known_grapheme_breaks/0","title":"Unicode.GraphemeClusterBreak.known_grapheme_breaks/0","type":"function","doc":"Returns a list of known Unicode grapheme cluster break names. This function does not return the names of any grapheme cluster break aliases."},{"ref":"Unicode.IndicSyllabicCategory.html","title":"Unicode.IndicSyllabicCategory","type":"module","doc":"Functions to introspect Unicode indic syllabic categories for binaries (Strings) and codepoints."},{"ref":"Unicode.IndicSyllabicCategory.html#aliases/0","title":"Unicode.IndicSyllabicCategory.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode indic syllabic categorys. An alias is an alternative name for referring to a indic syllabic category. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.IndicSyllabicCategory.html#count/1","title":"Unicode.IndicSyllabicCategory.count/1","type":"function","doc":"Returns the count of the number of characters for a given indic syllabic category. Example iex&gt; Unicode.IndicSyllabicCategory.count(:bindu) 91"},{"ref":"Unicode.IndicSyllabicCategory.html#fetch/1","title":"Unicode.IndicSyllabicCategory.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given indic syllabic category as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.IndicSyllabicCategory.html#get/1","title":"Unicode.IndicSyllabicCategory.get/1","type":"function","doc":"Returns the Unicode ranges for a given indic syllabic category as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.IndicSyllabicCategory.html#indic_syllabic_categories/0","title":"Unicode.IndicSyllabicCategory.indic_syllabic_categories/0","type":"function","doc":"Returns the map of Unicode indic syllabic categorys. The indic syllabic category name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.IndicSyllabicCategory.html#indic_syllabic_category/1","title":"Unicode.IndicSyllabicCategory.indic_syllabic_category/1","type":"function","doc":"Returns the indic syllabic category name(s) for the given binary or codepoint. In the case of a codepoint, a single indic syllabic category name is returned. For a binary a list of distinct indic syllabic category names represented by the lines in the binary is returned."},{"ref":"Unicode.IndicSyllabicCategory.html#known_indic_syllabic_categories/0","title":"Unicode.IndicSyllabicCategory.known_indic_syllabic_categories/0","type":"function","doc":"Returns a list of known Unicode indic syllabic category names. This function does not return the names of any indic syllabic category aliases."},{"ref":"Unicode.LineBreak.html","title":"Unicode.LineBreak","type":"module","doc":"Functions to introspect Unicode line breaks for binaries (Strings) and codepoints."},{"ref":"Unicode.LineBreak.html#aliases/0","title":"Unicode.LineBreak.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode line breaks. An alias is an alternative name for referring to a line break. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.LineBreak.html#count/1","title":"Unicode.LineBreak.count/1","type":"function","doc":"Returns the count of the number of characters for a given line_break. Example iex&gt; Unicode.LineBreak.count(:al) 21400"},{"ref":"Unicode.LineBreak.html#fetch/1","title":"Unicode.LineBreak.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given line break as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.LineBreak.html#get/1","title":"Unicode.LineBreak.get/1","type":"function","doc":"Returns the Unicode ranges for a given line break as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.LineBreak.html#known_line_breaks/0","title":"Unicode.LineBreak.known_line_breaks/0","type":"function","doc":"Returns a list of known Unicode line break names. This function does not return the names of any line break aliases."},{"ref":"Unicode.LineBreak.html#line_break/1","title":"Unicode.LineBreak.line_break/1","type":"function","doc":"Returns the line break name(s) for the given binary or codepoint. In the case of a codepoint, a single line_break name is returned. For a binary a list of distinct line break names represented by the lines in the binary is returned."},{"ref":"Unicode.LineBreak.html#line_breaks/0","title":"Unicode.LineBreak.line_breaks/0","type":"function","doc":"Returns the map of Unicode line breaks. The line break name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.Property.html","title":"Unicode.Property","type":"module","doc":"Functions to introspect Unicode properties for binaries (Strings) and codepoints."},{"ref":"Unicode.Property.html#aliases/0","title":"Unicode.Property.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode blocks. An alias is an alternative name for referring to a block. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.Property.html#alphabetic/1","title":"Unicode.Property.alphabetic/1","type":"function","doc":"Returns :alphabetic or nil indicating if the codepoint or string has the property :alphabetic. For string parameters, all codepoints in the string must have the :alphabetic property in order for the result to :alphabetic."},{"ref":"Unicode.Property.html#alphabetic?/1","title":"Unicode.Property.alphabetic?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :alphabetic. For string parameters, all codepoints in the string must have the :alphabetic property in order for the result to be true."},{"ref":"Unicode.Property.html#alphanumeric/1","title":"Unicode.Property.alphanumeric/1","type":"function","doc":"Returns :alphanumeric or nil based upon whether the given codepoint or binary is all alphanumeric characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.alphanumeric &quot;123abc&quot; :alphanumeric iex&gt; Unicode.Property.alphanumeric &quot;???&quot; nil"},{"ref":"Unicode.Property.html#alphanumeric?/1","title":"Unicode.Property.alphanumeric?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all alphanumeric characters. Example iex&gt; Unicode.Property.alphanumeric? &quot;123abc&quot; true iex&gt; Unicode.Property.alphanumeric? &quot;⅔&quot; false"},{"ref":"Unicode.Property.html#ascii_hex_digit/1","title":"Unicode.Property.ascii_hex_digit/1","type":"function","doc":"Returns :ascii_hex_digit or nil indicating if the codepoint or string has the property :ascii_hex_digit. For string parameters, all codepoints in the string must have the :ascii_hex_digit property in order for the result to :ascii_hex_digit."},{"ref":"Unicode.Property.html#ascii_hex_digit?/1","title":"Unicode.Property.ascii_hex_digit?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :ascii_hex_digit. For string parameters, all codepoints in the string must have the :ascii_hex_digit property in order for the result to be true."},{"ref":"Unicode.Property.html#bidi_control/1","title":"Unicode.Property.bidi_control/1","type":"function","doc":"Returns :bidi_control or nil indicating if the codepoint or string has the property :bidi_control. For string parameters, all codepoints in the string must have the :bidi_control property in order for the result to :bidi_control."},{"ref":"Unicode.Property.html#bidi_control?/1","title":"Unicode.Property.bidi_control?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :bidi_control. For string parameters, all codepoints in the string must have the :bidi_control property in order for the result to be true."},{"ref":"Unicode.Property.html#case_ignorable/1","title":"Unicode.Property.case_ignorable/1","type":"function","doc":"Returns :case_ignorable or nil indicating if the codepoint or string has the property :case_ignorable. For string parameters, all codepoints in the string must have the :case_ignorable property in order for the result to :case_ignorable."},{"ref":"Unicode.Property.html#case_ignorable?/1","title":"Unicode.Property.case_ignorable?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :case_ignorable. For string parameters, all codepoints in the string must have the :case_ignorable property in order for the result to be true."},{"ref":"Unicode.Property.html#cased/1","title":"Unicode.Property.cased/1","type":"function","doc":"Returns :cased or nil indicating if the codepoint or string has the property :cased. For string parameters, all codepoints in the string must have the :cased property in order for the result to :cased."},{"ref":"Unicode.Property.html#cased?/1","title":"Unicode.Property.cased?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :cased. For string parameters, all codepoints in the string must have the :cased property in order for the result to be true."},{"ref":"Unicode.Property.html#changes_when_casefolded/1","title":"Unicode.Property.changes_when_casefolded/1","type":"function","doc":"Returns :changes_when_casefolded or nil indicating if the codepoint or string has the property :changes_when_casefolded. For string parameters, all codepoints in the string must have the :changes_when_casefolded property in order for the result to :changes_when_casefolded."},{"ref":"Unicode.Property.html#changes_when_casefolded?/1","title":"Unicode.Property.changes_when_casefolded?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :changes_when_casefolded. For string parameters, all codepoints in the string must have the :changes_when_casefolded property in order for the result to be true."},{"ref":"Unicode.Property.html#changes_when_casemapped/1","title":"Unicode.Property.changes_when_casemapped/1","type":"function","doc":"Returns :changes_when_casemapped or nil indicating if the codepoint or string has the property :changes_when_casemapped. For string parameters, all codepoints in the string must have the :changes_when_casemapped property in order for the result to :changes_when_casemapped."},{"ref":"Unicode.Property.html#changes_when_casemapped?/1","title":"Unicode.Property.changes_when_casemapped?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :changes_when_casemapped. For string parameters, all codepoints in the string must have the :changes_when_casemapped property in order for the result to be true."},{"ref":"Unicode.Property.html#changes_when_lowercased/1","title":"Unicode.Property.changes_when_lowercased/1","type":"function","doc":"Returns :changes_when_lowercased or nil indicating if the codepoint or string has the property :changes_when_lowercased. For string parameters, all codepoints in the string must have the :changes_when_lowercased property in order for the result to :changes_when_lowercased."},{"ref":"Unicode.Property.html#changes_when_lowercased?/1","title":"Unicode.Property.changes_when_lowercased?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :changes_when_lowercased. For string parameters, all codepoints in the string must have the :changes_when_lowercased property in order for the result to be true."},{"ref":"Unicode.Property.html#changes_when_titlecased/1","title":"Unicode.Property.changes_when_titlecased/1","type":"function","doc":"Returns :changes_when_titlecased or nil indicating if the codepoint or string has the property :changes_when_titlecased. For string parameters, all codepoints in the string must have the :changes_when_titlecased property in order for the result to :changes_when_titlecased."},{"ref":"Unicode.Property.html#changes_when_titlecased?/1","title":"Unicode.Property.changes_when_titlecased?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :changes_when_titlecased. For string parameters, all codepoints in the string must have the :changes_when_titlecased property in order for the result to be true."},{"ref":"Unicode.Property.html#changes_when_uppercased/1","title":"Unicode.Property.changes_when_uppercased/1","type":"function","doc":"Returns :changes_when_uppercased or nil indicating if the codepoint or string has the property :changes_when_uppercased. For string parameters, all codepoints in the string must have the :changes_when_uppercased property in order for the result to :changes_when_uppercased."},{"ref":"Unicode.Property.html#changes_when_uppercased?/1","title":"Unicode.Property.changes_when_uppercased?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :changes_when_uppercased. For string parameters, all codepoints in the string must have the :changes_when_uppercased property in order for the result to be true."},{"ref":"Unicode.Property.html#count/1","title":"Unicode.Property.count/1","type":"function","doc":"Returns the count of the number of characters for a given property. Example iex&gt; Unicode.Property.count(:lowercase) 2344"},{"ref":"Unicode.Property.html#dash/1","title":"Unicode.Property.dash/1","type":"function","doc":"Returns :dash or nil indicating if the codepoint or string has the property :dash. For string parameters, all codepoints in the string must have the :dash property in order for the result to :dash."},{"ref":"Unicode.Property.html#dash?/1","title":"Unicode.Property.dash?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :dash. For string parameters, all codepoints in the string must have the :dash property in order for the result to be true."},{"ref":"Unicode.Property.html#default_ignorable_code_point/1","title":"Unicode.Property.default_ignorable_code_point/1","type":"function","doc":"Returns :default_ignorable_code_point or nil indicating if the codepoint or string has the property :default_ignorable_code_point. For string parameters, all codepoints in the string must have the :default_ignorable_code_point property in order for the result to :default_ignorable_code_point."},{"ref":"Unicode.Property.html#default_ignorable_code_point?/1","title":"Unicode.Property.default_ignorable_code_point?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :default_ignorable_code_point. For string parameters, all codepoints in the string must have the :default_ignorable_code_point property in order for the result to be true."},{"ref":"Unicode.Property.html#deprecated/1","title":"Unicode.Property.deprecated/1","type":"function","doc":"Returns :deprecated or nil indicating if the codepoint or string has the property :deprecated. For string parameters, all codepoints in the string must have the :deprecated property in order for the result to :deprecated."},{"ref":"Unicode.Property.html#deprecated?/1","title":"Unicode.Property.deprecated?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :deprecated. For string parameters, all codepoints in the string must have the :deprecated property in order for the result to be true."},{"ref":"Unicode.Property.html#diacritic/1","title":"Unicode.Property.diacritic/1","type":"function","doc":"Returns :diacritic or nil indicating if the codepoint or string has the property :diacritic. For string parameters, all codepoints in the string must have the :diacritic property in order for the result to :diacritic."},{"ref":"Unicode.Property.html#diacritic?/1","title":"Unicode.Property.diacritic?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :diacritic. For string parameters, all codepoints in the string must have the :diacritic property in order for the result to be true."},{"ref":"Unicode.Property.html#extended_numeric/1","title":"Unicode.Property.extended_numeric/1","type":"function","doc":"Returns :extended_numeric or nil based upon whether the given codepoint or binary is all alphanumeric characters. Extended numberic includes fractions, superscripts, subscripts and other characters in the category No. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.extended_numeric &quot;123&quot; :extended_numeric iex&gt; Unicode.Property.extended_numeric &quot;⅔&quot; :extended_numeric iex&gt; Unicode.Property.extended_numeric &quot;-123&quot; nil"},{"ref":"Unicode.Property.html#extended_numeric?/1","title":"Unicode.Property.extended_numeric?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all numberic characters. Example iex&gt; Unicode.Property.extended_numeric? &quot;123&quot; true iex&gt; Unicode.Property.extended_numeric? &quot;⅔&quot; true"},{"ref":"Unicode.Property.html#extender/1","title":"Unicode.Property.extender/1","type":"function","doc":"Returns :extender or nil indicating if the codepoint or string has the property :extender. For string parameters, all codepoints in the string must have the :extender property in order for the result to :extender."},{"ref":"Unicode.Property.html#extender?/1","title":"Unicode.Property.extender?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :extender. For string parameters, all codepoints in the string must have the :extender property in order for the result to be true."},{"ref":"Unicode.Property.html#fetch/1","title":"Unicode.Property.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given block as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.Property.html#get/1","title":"Unicode.Property.get/1","type":"function","doc":"Returns the Unicode ranges for a given block as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.Property.html#grapheme_base/1","title":"Unicode.Property.grapheme_base/1","type":"function","doc":"Returns :grapheme_base or nil indicating if the codepoint or string has the property :grapheme_base. For string parameters, all codepoints in the string must have the :grapheme_base property in order for the result to :grapheme_base."},{"ref":"Unicode.Property.html#grapheme_base?/1","title":"Unicode.Property.grapheme_base?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :grapheme_base. For string parameters, all codepoints in the string must have the :grapheme_base property in order for the result to be true."},{"ref":"Unicode.Property.html#grapheme_extend/1","title":"Unicode.Property.grapheme_extend/1","type":"function","doc":"Returns :grapheme_extend or nil indicating if the codepoint or string has the property :grapheme_extend. For string parameters, all codepoints in the string must have the :grapheme_extend property in order for the result to :grapheme_extend."},{"ref":"Unicode.Property.html#grapheme_extend?/1","title":"Unicode.Property.grapheme_extend?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :grapheme_extend. For string parameters, all codepoints in the string must have the :grapheme_extend property in order for the result to be true."},{"ref":"Unicode.Property.html#grapheme_link/1","title":"Unicode.Property.grapheme_link/1","type":"function","doc":"Returns :grapheme_link or nil indicating if the codepoint or string has the property :grapheme_link. For string parameters, all codepoints in the string must have the :grapheme_link property in order for the result to :grapheme_link."},{"ref":"Unicode.Property.html#grapheme_link?/1","title":"Unicode.Property.grapheme_link?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :grapheme_link. For string parameters, all codepoints in the string must have the :grapheme_link property in order for the result to be true."},{"ref":"Unicode.Property.html#hex_digit/1","title":"Unicode.Property.hex_digit/1","type":"function","doc":"Returns :hex_digit or nil indicating if the codepoint or string has the property :hex_digit. For string parameters, all codepoints in the string must have the :hex_digit property in order for the result to :hex_digit."},{"ref":"Unicode.Property.html#hex_digit?/1","title":"Unicode.Property.hex_digit?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :hex_digit. For string parameters, all codepoints in the string must have the :hex_digit property in order for the result to be true."},{"ref":"Unicode.Property.html#hyphen/1","title":"Unicode.Property.hyphen/1","type":"function","doc":"Returns :hyphen or nil indicating if the codepoint or string has the property :hyphen. For string parameters, all codepoints in the string must have the :hyphen property in order for the result to :hyphen."},{"ref":"Unicode.Property.html#hyphen?/1","title":"Unicode.Property.hyphen?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :hyphen. For string parameters, all codepoints in the string must have the :hyphen property in order for the result to be true."},{"ref":"Unicode.Property.html#id_continue/1","title":"Unicode.Property.id_continue/1","type":"function","doc":"Returns :id_continue or nil indicating if the codepoint or string has the property :id_continue. For string parameters, all codepoints in the string must have the :id_continue property in order for the result to :id_continue."},{"ref":"Unicode.Property.html#id_continue?/1","title":"Unicode.Property.id_continue?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :id_continue. For string parameters, all codepoints in the string must have the :id_continue property in order for the result to be true."},{"ref":"Unicode.Property.html#id_start/1","title":"Unicode.Property.id_start/1","type":"function","doc":"Returns :id_start or nil indicating if the codepoint or string has the property :id_start. For string parameters, all codepoints in the string must have the :id_start property in order for the result to :id_start."},{"ref":"Unicode.Property.html#id_start?/1","title":"Unicode.Property.id_start?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :id_start. For string parameters, all codepoints in the string must have the :id_start property in order for the result to be true."},{"ref":"Unicode.Property.html#ideographic/1","title":"Unicode.Property.ideographic/1","type":"function","doc":"Returns :ideographic or nil indicating if the codepoint or string has the property :ideographic. For string parameters, all codepoints in the string must have the :ideographic property in order for the result to :ideographic."},{"ref":"Unicode.Property.html#ideographic?/1","title":"Unicode.Property.ideographic?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :ideographic. For string parameters, all codepoints in the string must have the :ideographic property in order for the result to be true."},{"ref":"Unicode.Property.html#ids_binary_operator/1","title":"Unicode.Property.ids_binary_operator/1","type":"function","doc":"Returns :ids_binary_operator or nil indicating if the codepoint or string has the property :ids_binary_operator. For string parameters, all codepoints in the string must have the :ids_binary_operator property in order for the result to :ids_binary_operator."},{"ref":"Unicode.Property.html#ids_binary_operator?/1","title":"Unicode.Property.ids_binary_operator?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :ids_binary_operator. For string parameters, all codepoints in the string must have the :ids_binary_operator property in order for the result to be true."},{"ref":"Unicode.Property.html#ids_trinary_operator/1","title":"Unicode.Property.ids_trinary_operator/1","type":"function","doc":"Returns :ids_trinary_operator or nil indicating if the codepoint or string has the property :ids_trinary_operator. For string parameters, all codepoints in the string must have the :ids_trinary_operator property in order for the result to :ids_trinary_operator."},{"ref":"Unicode.Property.html#ids_trinary_operator?/1","title":"Unicode.Property.ids_trinary_operator?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :ids_trinary_operator. For string parameters, all codepoints in the string must have the :ids_trinary_operator property in order for the result to be true."},{"ref":"Unicode.Property.html#join_control/1","title":"Unicode.Property.join_control/1","type":"function","doc":"Returns :join_control or nil indicating if the codepoint or string has the property :join_control. For string parameters, all codepoints in the string must have the :join_control property in order for the result to :join_control."},{"ref":"Unicode.Property.html#join_control?/1","title":"Unicode.Property.join_control?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :join_control. For string parameters, all codepoints in the string must have the :join_control property in order for the result to be true."},{"ref":"Unicode.Property.html#known_properties/0","title":"Unicode.Property.known_properties/0","type":"function","doc":"Returns a list of known Unicode property names. This function does not return the names of any property aliases."},{"ref":"Unicode.Property.html#logical_order_exception/1","title":"Unicode.Property.logical_order_exception/1","type":"function","doc":"Returns :logical_order_exception or nil indicating if the codepoint or string has the property :logical_order_exception. For string parameters, all codepoints in the string must have the :logical_order_exception property in order for the result to :logical_order_exception."},{"ref":"Unicode.Property.html#logical_order_exception?/1","title":"Unicode.Property.logical_order_exception?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :logical_order_exception. For string parameters, all codepoints in the string must have the :logical_order_exception property in order for the result to be true."},{"ref":"Unicode.Property.html#lowercase/1","title":"Unicode.Property.lowercase/1","type":"function","doc":"Returns :lowercase or nil indicating if the codepoint or string has the property :lowercase. For string parameters, all codepoints in the string must have the :lowercase property in order for the result to :lowercase."},{"ref":"Unicode.Property.html#lowercase?/1","title":"Unicode.Property.lowercase?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :lowercase. For string parameters, all codepoints in the string must have the :lowercase property in order for the result to be true."},{"ref":"Unicode.Property.html#math/1","title":"Unicode.Property.math/1","type":"function","doc":"Returns :math or nil indicating if the codepoint or string has the property :math. For string parameters, all codepoints in the string must have the :math property in order for the result to :math."},{"ref":"Unicode.Property.html#math?/1","title":"Unicode.Property.math?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :math. For string parameters, all codepoints in the string must have the :math property in order for the result to be true."},{"ref":"Unicode.Property.html#noncharacter_code_point/1","title":"Unicode.Property.noncharacter_code_point/1","type":"function","doc":"Returns :noncharacter_code_point or nil indicating if the codepoint or string has the property :noncharacter_code_point. For string parameters, all codepoints in the string must have the :noncharacter_code_point property in order for the result to :noncharacter_code_point."},{"ref":"Unicode.Property.html#noncharacter_code_point?/1","title":"Unicode.Property.noncharacter_code_point?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :noncharacter_code_point. For string parameters, all codepoints in the string must have the :noncharacter_code_point property in order for the result to be true."},{"ref":"Unicode.Property.html#numeric/1","title":"Unicode.Property.numeric/1","type":"function","doc":"Returns :numeric or nil based upon whether the given codepoint or binary is all numeric characters. This is useful when the desired result is truthy or falsy Example iex&gt; Unicode.Property.numeric &quot;123&quot; :numeric iex&gt; Unicode.Property.numeric &quot;123a&quot; nil"},{"ref":"Unicode.Property.html#numeric?/1","title":"Unicode.Property.numeric?/1","type":"function","doc":"Returns a boolean based upon whether the given codepoint or binary is all numeric characters. Example iex&gt; Unicode.Property.numeric? &quot;123&quot; true iex&gt; Unicode.Property.numeric? &quot;123a&quot; false"},{"ref":"Unicode.Property.html#other_alphabetic/1","title":"Unicode.Property.other_alphabetic/1","type":"function","doc":"Returns :other_alphabetic or nil indicating if the codepoint or string has the property :other_alphabetic. For string parameters, all codepoints in the string must have the :other_alphabetic property in order for the result to :other_alphabetic."},{"ref":"Unicode.Property.html#other_alphabetic?/1","title":"Unicode.Property.other_alphabetic?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :other_alphabetic. For string parameters, all codepoints in the string must have the :other_alphabetic property in order for the result to be true."},{"ref":"Unicode.Property.html#other_default_ignorable_code_point/1","title":"Unicode.Property.other_default_ignorable_code_point/1","type":"function","doc":"Returns :other_default_ignorable_code_point or nil indicating if the codepoint or string has the property :other_default_ignorable_code_point. For string parameters, all codepoints in the string must have the :other_default_ignorable_code_point property in order for the result to :other_default_ignorable_code_point."},{"ref":"Unicode.Property.html#other_default_ignorable_code_point?/1","title":"Unicode.Property.other_default_ignorable_code_point?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :other_default_ignorable_code_point. For string parameters, all codepoints in the string must have the :other_default_ignorable_code_point property in order for the result to be true."},{"ref":"Unicode.Property.html#other_grapheme_extend/1","title":"Unicode.Property.other_grapheme_extend/1","type":"function","doc":"Returns :other_grapheme_extend or nil indicating if the codepoint or string has the property :other_grapheme_extend. For string parameters, all codepoints in the string must have the :other_grapheme_extend property in order for the result to :other_grapheme_extend."},{"ref":"Unicode.Property.html#other_grapheme_extend?/1","title":"Unicode.Property.other_grapheme_extend?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :other_grapheme_extend. For string parameters, all codepoints in the string must have the :other_grapheme_extend property in order for the result to be true."},{"ref":"Unicode.Property.html#other_id_continue/1","title":"Unicode.Property.other_id_continue/1","type":"function","doc":"Returns :other_id_continue or nil indicating if the codepoint or string has the property :other_id_continue. For string parameters, all codepoints in the string must have the :other_id_continue property in order for the result to :other_id_continue."},{"ref":"Unicode.Property.html#other_id_continue?/1","title":"Unicode.Property.other_id_continue?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :other_id_continue. For string parameters, all codepoints in the string must have the :other_id_continue property in order for the result to be true."},{"ref":"Unicode.Property.html#other_id_start/1","title":"Unicode.Property.other_id_start/1","type":"function","doc":"Returns :other_id_start or nil indicating if the codepoint or string has the property :other_id_start. For string parameters, all codepoints in the string must have the :other_id_start property in order for the result to :other_id_start."},{"ref":"Unicode.Property.html#other_id_start?/1","title":"Unicode.Property.other_id_start?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :other_id_start. For string parameters, all codepoints in the string must have the :other_id_start property in order for the result to be true."},{"ref":"Unicode.Property.html#other_lowercase/1","title":"Unicode.Property.other_lowercase/1","type":"function","doc":"Returns :other_lowercase or nil indicating if the codepoint or string has the property :other_lowercase. For string parameters, all codepoints in the string must have the :other_lowercase property in order for the result to :other_lowercase."},{"ref":"Unicode.Property.html#other_lowercase?/1","title":"Unicode.Property.other_lowercase?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :other_lowercase. For string parameters, all codepoints in the string must have the :other_lowercase property in order for the result to be true."},{"ref":"Unicode.Property.html#other_math/1","title":"Unicode.Property.other_math/1","type":"function","doc":"Returns :other_math or nil indicating if the codepoint or string has the property :other_math. For string parameters, all codepoints in the string must have the :other_math property in order for the result to :other_math."},{"ref":"Unicode.Property.html#other_math?/1","title":"Unicode.Property.other_math?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :other_math. For string parameters, all codepoints in the string must have the :other_math property in order for the result to be true."},{"ref":"Unicode.Property.html#other_uppercase/1","title":"Unicode.Property.other_uppercase/1","type":"function","doc":"Returns :other_uppercase or nil indicating if the codepoint or string has the property :other_uppercase. For string parameters, all codepoints in the string must have the :other_uppercase property in order for the result to :other_uppercase."},{"ref":"Unicode.Property.html#other_uppercase?/1","title":"Unicode.Property.other_uppercase?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :other_uppercase. For string parameters, all codepoints in the string must have the :other_uppercase property in order for the result to be true."},{"ref":"Unicode.Property.html#pattern_syntax/1","title":"Unicode.Property.pattern_syntax/1","type":"function","doc":"Returns :pattern_syntax or nil indicating if the codepoint or string has the property :pattern_syntax. For string parameters, all codepoints in the string must have the :pattern_syntax property in order for the result to :pattern_syntax."},{"ref":"Unicode.Property.html#pattern_syntax?/1","title":"Unicode.Property.pattern_syntax?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :pattern_syntax. For string parameters, all codepoints in the string must have the :pattern_syntax property in order for the result to be true."},{"ref":"Unicode.Property.html#pattern_white_space/1","title":"Unicode.Property.pattern_white_space/1","type":"function","doc":"Returns :pattern_white_space or nil indicating if the codepoint or string has the property :pattern_white_space. For string parameters, all codepoints in the string must have the :pattern_white_space property in order for the result to :pattern_white_space."},{"ref":"Unicode.Property.html#pattern_white_space?/1","title":"Unicode.Property.pattern_white_space?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :pattern_white_space. For string parameters, all codepoints in the string must have the :pattern_white_space property in order for the result to be true."},{"ref":"Unicode.Property.html#prepended_concatenation_mark/1","title":"Unicode.Property.prepended_concatenation_mark/1","type":"function","doc":"Returns :prepended_concatenation_mark or nil indicating if the codepoint or string has the property :prepended_concatenation_mark. For string parameters, all codepoints in the string must have the :prepended_concatenation_mark property in order for the result to :prepended_concatenation_mark."},{"ref":"Unicode.Property.html#prepended_concatenation_mark?/1","title":"Unicode.Property.prepended_concatenation_mark?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :prepended_concatenation_mark. For string parameters, all codepoints in the string must have the :prepended_concatenation_mark property in order for the result to be true."},{"ref":"Unicode.Property.html#properties/0","title":"Unicode.Property.properties/0","type":"function","doc":"Returns the map of Unicode properties. The property name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.Property.html#properties/1","title":"Unicode.Property.properties/1","type":"function","doc":"Returns the property name(s) for the given binary or codepoint. In the case of a codepoint, a single list of properties for that codepoint name is returned. For a binary a list of list for each codepoint in the binary is returned."},{"ref":"Unicode.Property.html#quotation_mark/1","title":"Unicode.Property.quotation_mark/1","type":"function","doc":"Returns :quotation_mark or nil indicating if the codepoint or string has the property :quotation_mark. For string parameters, all codepoints in the string must have the :quotation_mark property in order for the result to :quotation_mark."},{"ref":"Unicode.Property.html#quotation_mark?/1","title":"Unicode.Property.quotation_mark?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :quotation_mark. For string parameters, all codepoints in the string must have the :quotation_mark property in order for the result to be true."},{"ref":"Unicode.Property.html#radical/1","title":"Unicode.Property.radical/1","type":"function","doc":"Returns :radical or nil indicating if the codepoint or string has the property :radical. For string parameters, all codepoints in the string must have the :radical property in order for the result to :radical."},{"ref":"Unicode.Property.html#radical?/1","title":"Unicode.Property.radical?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :radical. For string parameters, all codepoints in the string must have the :radical property in order for the result to be true."},{"ref":"Unicode.Property.html#regional_indicator/1","title":"Unicode.Property.regional_indicator/1","type":"function","doc":"Returns :regional_indicator or nil indicating if the codepoint or string has the property :regional_indicator. For string parameters, all codepoints in the string must have the :regional_indicator property in order for the result to :regional_indicator."},{"ref":"Unicode.Property.html#regional_indicator?/1","title":"Unicode.Property.regional_indicator?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :regional_indicator. For string parameters, all codepoints in the string must have the :regional_indicator property in order for the result to be true."},{"ref":"Unicode.Property.html#sentence_terminal/1","title":"Unicode.Property.sentence_terminal/1","type":"function","doc":"Returns :sentence_terminal or nil indicating if the codepoint or string has the property :sentence_terminal. For string parameters, all codepoints in the string must have the :sentence_terminal property in order for the result to :sentence_terminal."},{"ref":"Unicode.Property.html#sentence_terminal?/1","title":"Unicode.Property.sentence_terminal?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :sentence_terminal. For string parameters, all codepoints in the string must have the :sentence_terminal property in order for the result to be true."},{"ref":"Unicode.Property.html#servers/0","title":"Unicode.Property.servers/0","type":"function","doc":"Returns a map of properties to the module that serves that property."},{"ref":"Unicode.Property.html#soft_dotted/1","title":"Unicode.Property.soft_dotted/1","type":"function","doc":"Returns :soft_dotted or nil indicating if the codepoint or string has the property :soft_dotted. For string parameters, all codepoints in the string must have the :soft_dotted property in order for the result to :soft_dotted."},{"ref":"Unicode.Property.html#soft_dotted?/1","title":"Unicode.Property.soft_dotted?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :soft_dotted. For string parameters, all codepoints in the string must have the :soft_dotted property in order for the result to be true."},{"ref":"Unicode.Property.html#terminal_punctuation/1","title":"Unicode.Property.terminal_punctuation/1","type":"function","doc":"Returns :terminal_punctuation or nil indicating if the codepoint or string has the property :terminal_punctuation. For string parameters, all codepoints in the string must have the :terminal_punctuation property in order for the result to :terminal_punctuation."},{"ref":"Unicode.Property.html#terminal_punctuation?/1","title":"Unicode.Property.terminal_punctuation?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :terminal_punctuation. For string parameters, all codepoints in the string must have the :terminal_punctuation property in order for the result to be true."},{"ref":"Unicode.Property.html#unified_ideograph/1","title":"Unicode.Property.unified_ideograph/1","type":"function","doc":"Returns :unified_ideograph or nil indicating if the codepoint or string has the property :unified_ideograph. For string parameters, all codepoints in the string must have the :unified_ideograph property in order for the result to :unified_ideograph."},{"ref":"Unicode.Property.html#unified_ideograph?/1","title":"Unicode.Property.unified_ideograph?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :unified_ideograph. For string parameters, all codepoints in the string must have the :unified_ideograph property in order for the result to be true."},{"ref":"Unicode.Property.html#uppercase/1","title":"Unicode.Property.uppercase/1","type":"function","doc":"Returns :uppercase or nil indicating if the codepoint or string has the property :uppercase. For string parameters, all codepoints in the string must have the :uppercase property in order for the result to :uppercase."},{"ref":"Unicode.Property.html#uppercase?/1","title":"Unicode.Property.uppercase?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :uppercase. For string parameters, all codepoints in the string must have the :uppercase property in order for the result to be true."},{"ref":"Unicode.Property.html#variation_selector/1","title":"Unicode.Property.variation_selector/1","type":"function","doc":"Returns :variation_selector or nil indicating if the codepoint or string has the property :variation_selector. For string parameters, all codepoints in the string must have the :variation_selector property in order for the result to :variation_selector."},{"ref":"Unicode.Property.html#variation_selector?/1","title":"Unicode.Property.variation_selector?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :variation_selector. For string parameters, all codepoints in the string must have the :variation_selector property in order for the result to be true."},{"ref":"Unicode.Property.html#white_space/1","title":"Unicode.Property.white_space/1","type":"function","doc":"Returns :white_space or nil indicating if the codepoint or string has the property :white_space. For string parameters, all codepoints in the string must have the :white_space property in order for the result to :white_space."},{"ref":"Unicode.Property.html#white_space?/1","title":"Unicode.Property.white_space?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :white_space. For string parameters, all codepoints in the string must have the :white_space property in order for the result to be true."},{"ref":"Unicode.Property.html#xid_continue/1","title":"Unicode.Property.xid_continue/1","type":"function","doc":"Returns :xid_continue or nil indicating if the codepoint or string has the property :xid_continue. For string parameters, all codepoints in the string must have the :xid_continue property in order for the result to :xid_continue."},{"ref":"Unicode.Property.html#xid_continue?/1","title":"Unicode.Property.xid_continue?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :xid_continue. For string parameters, all codepoints in the string must have the :xid_continue property in order for the result to be true."},{"ref":"Unicode.Property.html#xid_start/1","title":"Unicode.Property.xid_start/1","type":"function","doc":"Returns :xid_start or nil indicating if the codepoint or string has the property :xid_start. For string parameters, all codepoints in the string must have the :xid_start property in order for the result to :xid_start."},{"ref":"Unicode.Property.html#xid_start?/1","title":"Unicode.Property.xid_start?/1","type":"function","doc":"Returns a boolean indicating if the codepoint or string has the property :xid_start. For string parameters, all codepoints in the string must have the :xid_start property in order for the result to be true."},{"ref":"Unicode.Property.html#t:string_or_codepoint/0","title":"Unicode.Property.string_or_codepoint/0","type":"type","doc":""},{"ref":"Unicode.Script.html","title":"Unicode.Script","type":"module","doc":"Functions to introspect Unicode scripts for binaries (Strings) and codepoints."},{"ref":"Unicode.Script.html#aliases/0","title":"Unicode.Script.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode scripts. An alias is an alternative name for referring to a script. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.Script.html#count/1","title":"Unicode.Script.count/1","type":"function","doc":"Returns the count of the number of characters for a given script. Example iex&gt; Unicode.Script.count(&quot;mongolian&quot;) 167"},{"ref":"Unicode.Script.html#fetch/1","title":"Unicode.Script.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given script as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.Script.html#get/1","title":"Unicode.Script.get/1","type":"function","doc":"Returns the Unicode ranges for a given script as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.Script.html#known_scripts/0","title":"Unicode.Script.known_scripts/0","type":"function","doc":"Returns a list of known Unicode script names. This function does not return the names of any script aliases."},{"ref":"Unicode.Script.html#script/1","title":"Unicode.Script.script/1","type":"function","doc":"Returns the script name(s) for the given binary or codepoint. In the case of a codepoint, a single script name is returned. For a binary a list of distinct script names represented by the graphemes in the binary is returned."},{"ref":"Unicode.Script.html#scripts/0","title":"Unicode.Script.scripts/0","type":"function","doc":"Returns the map of Unicode scripts. The script name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"Unicode.SentenceBreak.html","title":"Unicode.SentenceBreak","type":"module","doc":"Functions to introspect Unicode sentence breaks for binaries (Strings) and codepoints."},{"ref":"Unicode.SentenceBreak.html#aliases/0","title":"Unicode.SentenceBreak.aliases/0","type":"function","doc":"Returns a map of aliases for Unicode sentence breaks. An alias is an alternative name for referring to a sentence break. Aliases are resolved by the fetch/1 and get/1 functions."},{"ref":"Unicode.SentenceBreak.html#count/1","title":"Unicode.SentenceBreak.count/1","type":"function","doc":"Returns the count of the number of characters for a given sentence break. Example iex&gt; Unicode.SentenceBreak.count(:extend) 2395"},{"ref":"Unicode.SentenceBreak.html#fetch/1","title":"Unicode.SentenceBreak.fetch/1","type":"function","doc":"Returns the Unicode ranges for a given sentence break as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either {:ok, range_list} or :error."},{"ref":"Unicode.SentenceBreak.html#get/1","title":"Unicode.SentenceBreak.get/1","type":"function","doc":"Returns the Unicode ranges for a given sentence break as a list of ranges as 2-tuples. Aliases are resolved by this function. Returns either range_list or nil."},{"ref":"Unicode.SentenceBreak.html#known_sentence_breaks/0","title":"Unicode.SentenceBreak.known_sentence_breaks/0","type":"function","doc":"Returns a list of known Unicode sentence break names. This function does not return the names of any sentence break aliases."},{"ref":"Unicode.SentenceBreak.html#sentence_break/1","title":"Unicode.SentenceBreak.sentence_break/1","type":"function","doc":"Returns the sentence break name(s) for the given binary or codepoint. In the case of a codepoint, a single sentence break name is returned. For a binary a list of distinct sentence break names represented by the graphemes in the binary is returned."},{"ref":"Unicode.SentenceBreak.html#sentence_breaks/0","title":"Unicode.SentenceBreak.sentence_breaks/0","type":"function","doc":"Returns the map of Unicode sentence breaks. The sentence break name is the map key and a list of codepoint ranges as tuples as the value."},{"ref":"readme.html","title":"Unicode","type":"extras","doc":"Unicode Functions to return information about Unicode codepoints. Elixir string are UTF8-encoded Unicode binaries. This is a flexible and complete encoding scheme for the worlds many scripts, characters and emjois. However since its a variable lenght encoding (using between one and four bytes for UTF8) it is harder to use high-performance byte-oriented functions to decompose strings. Since checking strings and codepoints for certain attributes - like whether they are upper case, or symbols, or whitespace - is a common occurrence, a performant approach to such detection is useful. It is tempting to assume the use of US ASCII encoding and checking only for characters in that range. For example it is very common to see code in Elixir checking codepoint in ?a..?z to check for lowercase alphabetic characters. When the underlying programming language has no canonical form for a string beyond bytes this may be considered acceptable - the programmer is defining the script domain as he or she sees fit. However Elixir string are declared to be UTF8 encoded Unicode string it seems appropriate to make it easier to determins the characteristics of codepoints (and strings) using this standard. The Elixir standard library does not provide introspection beyond that required to support casing (String.downcase/1, String.upcase/1, String.capitalize/1). This library aims to fill in the blanks a little bit."},{"ref":"readme.html#additional-unicode-libraries","title":"Unicode - Additional Unicode libraries","type":"extras","doc":"ex_unicode provides basic introspection into Unicode codepoints and strings. Additional libraries (either releases or in development) buil upon this library): unicode_set implements functions to parse and match on unicode sets unicode_guards is a simple library implementing common function guards using unicode_set and ex_unicode unicode_string is a library to implement efficient string splitting and replacing based upon unicode sets unicode_transform implements the Unicode transform specification."},{"ref":"readme.html#unicode-functions","title":"Unicode - Unicode Functions","type":"extras","doc":"The following is a partial list of functions included in the library. See the documentation for the relevant module for further information: Codepoint ranges These functions return the codepoints as list of 2-tuples for the given property: Unicode.Block.blocks/0 Unicode.Script.scripts/0 Unicode.GeneralCategory.categories/0 Unicode.CombiningClass.combining_classes/0 Unicode.GraphemeBreak.grapheme_breaks/0 Unicode.LineBreak.line_breaks/0 Unicode.SentenceBreak.sentence_breaks/0 Unicode.IndicSyllabicCategory.indic_syllabic_categories/0 Unicode.Property.properties/0 Basic introspection of codepoints and string The following functions return the block, script and category for codepoints and strings: Unicode.script/1 iex&gt; Unicode.script ?ä &quot;latin&quot; iex&gt; Unicode.script ?خ &quot;arabic&quot; iex&gt; Unicode.script ?अ &quot;devanagari&quot; Unicode.block/1 iex&gt; Unicode.block ?ä :latin_1_supplement iex&gt; Unicode.block ?A :basic_latin iex&gt; Unicode.block &quot;äA&quot; [:latin_1_supplement, :basic_latin] Unicode.category/1 iex&gt; Unicode.category ?ä :Ll iex&gt; Unicode.category ?A :Lu iex&gt; Unicode.category ?🧐 :So Unicode.properties/1 iex&gt; Unicode.properties 0x1bf0 [ :alphabetic, :case_ignorable, :grapheme_extend, :id_continue, :other_alphabetic, :xid_continue ] iex&gt; Unicode.properties ?A [ :alphabetic, :ascii_hex_digit, :cased, :changes_when_casefolded, :changes_when_casemapped, :changes_when_lowercased, :grapheme_base, :hex_digit, :id_continue, :id_start, :uppercase, :xid_continue, :xid_start ] iex&gt; Unicode.properties ?+ [:grapheme_base, :math, :pattern_syntax] iex&gt; Unicode.properties &quot;a1+&quot; [ [ :alphabetic, :ascii_hex_digit, :cased, :changes_when_casemapped, :changes_when_titlecased, :changes_when_uppercased, :grapheme_base, :hex_digit, :id_continue, :id_start, :lowercase, :xid_continue, :xid_start ], [ :ascii_hex_digit, :emoji, :grapheme_base, :hex_digit, :id_continue, :xid_continue ], [:grapheme_base, :math, :pattern_syntax] ] Character classes These functions help filter codepoints and strings based upon their properties. They return a boolean result. Unicode.alphabetic?/1 Unicode.alphanumeric?/1 Unicode.digits?/1 Unicode.numeric?/1 Unicode.emoji?/1 Unicode.math?/1 Unicode.cased?/1 Unicode.lowercase?/1 Unicode.uppercase?/1 Any known property can be called as a function Unicode.Property.&lt;property_name&gt;(codepoint_or_string) or Unicode.Property.&lt;property_name&gt;?(codepoint_or_string) to return a boolean. Transformations The function Unicode.unaccent/1 attempts to transform a Unicode string into a subset of the Latin-1 alphabet by removing diacritical marks from text. It is not a full transformation (which will be available in the upcoming unicode_transform library.)"},{"ref":"readme.html#recognition","title":"Unicode - Recognition","type":"extras","doc":"The information functions are heavily inspired by @qqwy&#39;s elixir-unicode package and compatibility with some of the api is represented by including some of the doctests from that package."},{"ref":"readme.html#installation","title":"Unicode - Installation","type":"extras","doc":"The package can be installed by adding ex_unicode to your list of dependencies in mix.exs: def deps do [ {:ex_unicode, &quot;~&gt; 1.0&quot;} ] end The docs can be found at https://hexdocs.pm/ex_unicode."},{"ref":"license.html","title":"License","type":"extras","doc":"License Copyright 2018 Kip Cole Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License."},{"ref":"changelog.html","title":"Changelog for Unicode v1.5.0","type":"extras","doc":"Changelog for Unicode v1.5.0 This is the changelog for Unicode v1.5.0 released on March 14th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Add derived categories :printable: and :visible:. :printable: implements the same semnantics String.printable?/1. :visible: combines the categories [[:L:][:N:][:M:][:P:][:S:][:Zs:]]. Changelog for Unicode v1.4.1 This is the changelog for Unicode v1.4.1 released on March 11th, 2019. For older changelogs please consult the release tag on GitHub Bug Fixes Regenerate the assigned ranges for Unicode 13 Changelog for Unicode v1.4.0 This is the changelog for Unicode v1.4.0 released on March 11th, 2019. For older changelogs please consult the release tag on GitHub Enhancements Updates Unicode to version 13.0. As of March 2020, Unicode has introduced Unicode 13.0 and this data now forms the basis of ex_unicode version 1.40. Version 13 of Unicode adds 5,390 characters, for a total of 143,859 characters. These additions include four new scripts, for a total of 154 scripts, as well as 55 new emoji characters. Adds derived categories for various quotation marks. Although the unicode character database has a flag to indicate if a given codepoint is a quotation mark, the list does not include CJK quotation marks, dingbats or alternative encodings. Some additional derived categories are therefore added that are taken from Wikipedia. The added dervived categories are: QuoteMark - all quote marks QuoteMarkLeft - all quote marks used on the left QuoteMarkRight - quote marks used on the right QuoteMarkAmbidextrous - quote marks used either left or right QuoteMarkSingle - single quote marks QuoteMarkDouble - double quote marks These additional derived categories can be used in Unicode Sets, for example: iex&gt; Unicode.Set.match? ?&#39;, &quot;[[:quote_mark:]]&quot; true iex&gt; Unicode.Set.match? ?&#39;, &quot;[[:quote_mark_left:]]&quot; false iex&gt; Unicode.Set.match? ?&#39;, &quot;[[:quote_mark_ambidextrous:]]&quot; true ```` # Changelog for Unicode v1.3.1 This is the changelog for Unicode v1.3.1 released on January 8th, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/unicode/tags) ### Bug Fixes * Remove call to [`Code.ensure_compiled?/1`](https://hexdocs.pm/elixir/Code.html#ensure_compiled?/1) which is deprecated in Elixir 1.10.0. * Fix the ranges for the General Category `:assigned`. # Changelog for Unicode v1.3.0 This is the changelog for Unicode v1.3.0 released on December 3rd, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/unicode/tags) ### Breaking Changes * Changed two module names: `Unicode.Category` becomes [`Unicode.GeneralCategory`](Unicode.GeneralCategory.html) and `Unicode.CombiningClass` becomes [`Unicode.CanonicalCombiningClass`](Unicode.CanonicalCombiningClass.html). These names map directly to the Unicode standard names. It also means all property module names can be derived from the Unicode property name which is what the new `Unicode.servers/0` function does. ### Enhancements * Add property modules for line break, sentence break, grapheme cluster break and indic syllabic category. These properties are used by the CLDR and Unicode segmentation rules. * Add `Unicode.servers/0` that maps property names and aliases to a module name that serves that property. ### Bug fixes * Fixes `Unicode.aliases/0` to correctly use the aliases in `data/property_alias.txt` # Changelog for Unicode v1.2.0 This is the changelog for Unicode v1.2.0 released on November 27th, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/unicode/tags) ### Breaking Changes * Script names are now atoms instead of strings to be consistent with other properties ### Enhancements * Add `aliases/0`, `fetch/1` and `get/1` to [`Unicode.Property`](Unicode.Property.html) * Added additional properties to [`Unicode.Property`](Unicode.Property.html). The set now includes those from the UCD files `DerivedCoreProperties.txt` and `PropList.txt`. # Changelog for Unicode v1.1.0 This is the changelog for Unicode v1.1.0 released on November 23rd, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/unicode/tags) ### Breaking Changes * Removed `Unicode.Guards` from this library and moved them to the [unicode_set](https://hex.pm/packages/unicode_guards) package. ### Enhancements * `Unicode.Category.categories/0` now returns the super categories as well as the subcategories. These super categories are computed at compile time by consolidating the relevant subcategories. `Unicode.Category.category/1` will only return one category, and it will be the subcategory as it consistent with earlier releases. * Add [`Unicode.ranges/0`](Unicode.html#ranges/0) that returns all Unicode codepoints as a list of 2-tuples representing the disjoint ranges of valid codepoints. The list is in sorted order. * Add `aliases/0` for `Unicode.Category`, [`Unicode.Script`](Unicode.Script.html), [`Unicode.Block`](Unicode.Block.html), and `Unicode.CombiningClass` which returns the alias map for the relevant module. * Add `fetch/1` and `get/1` for `Unicode.Category`, [`Unicode.Script`](Unicode.Script.html), [`Unicode.Block`](Unicode.Block.html), and `Unicode.CombiningClass`. These functions leverage Unicode property value aliases for retrieving codepoints. * Add [`Unicode.fetch_property/1`](Unicode.html#fetch_property/1) and [`Unicode.get_property/1`](Unicode.html#get_property/1) that return the module responsible for handling a given Unicode property. * Add `Unicode.compact_ranges/1` that given a list of 2-tuple ranges will compact them into as small a list of contiguous blocks as possible * Documented all public functions # Changelog for Unicode v1.0.0 This is the changelog for Unicode v1.0.0 released on November 14th, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/unicode/tags) ### Breaking Changes * Rename the module prefix to [`Unicode`](Unicode.html) since this package is not linked in any way to the `Cldr` family. The hex package is renamed to `ex_unicode`. # Changelog for Cldr Unicode v0.7.1 This is the changelog for Unicode v0.7.1 released on November 12th, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags) ### Bug Fixes * Fixes `count/1` for blocks, scripts and categories * Replace deprecated [`String.normalize/2`](https://hexdocs.pm/elixir/String.html#normalize/2) with `:unicode.characters_to_nfd_binary/` for OTP release 20 and later. # Changelog for Cldr Unicode v0.7.0 This is the changelog for Unicode v0.7.0 released on November 12th, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags) ### Enhancements * Add `is_whitespace/1` guard generator # Changelog for Cldr Unicode v0.6.0 This is the changelog for Unicode v0.6.0 released on October 22nd, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags) ### Enhancements * Update to Emoji 12.1 # Changelog for Cldr Unicode v0.5.0 This is the changelog for Unicode v0.5.0 released on May 12th, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags) ### Enhancements * Update to Unicode 12.1 # Changelog for Cldr Unicode v0.4.0 This is the changelog for Unicode v0.4.0 released on April 30th, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags) ### Enhancements * Adds `Cldr.Unicode.unaccent/1` ### Breaking Changes * Block names are now atoms instead of strings # Changelog for Cldr Unicode v0.3.0 This is the changelog for Unicode v0.3.0 released on March 28th, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags) ### Enhancements * Updated to Unicode version 12 # Changelog for Cldr Unicode v0.2.0 This is the changelog for Unicode v0.2.0 released on February 24th, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags) ### Enhancements * Moves the public API to the `Cldr.Unicode` module. * Updates and adds documentation to all public functions. * Removes the text annotations from the compiled functions which materially reduces the size of the beam files. # Changelog for Cldr Unicode v0.1.0 This is the changelog for Unicode v0.1.0 released on February 23rd, 2019. For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags) ### Enhancements * Initial release"}]